package extnet

import (
	"context"
	"encoding/json"
	"net/http"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// ListRequest struct to get list of external network
type ListRequest struct {
	// Find by account ID
	// Required: false
	AccountID uint64 `url:"accountId,omitempty" json:"accountId,omitempty"`

	// Find by ID
	// Required: false
	ByID uint64 `url:"by_id,omitempty" json:"by_id,omitempty"`

	// Find by name
	// Required: false
	Name string `url:"name,omitempty" json:"name,omitempty"`

	// Find by network ip address
	// Required: false
	Network string `url:"network,omitempty" json:"network,omitempty"`

	// Find by vlan ID
	// Required: false
	VLANID uint64 `url:"vlanId,omitempty" json:"vlanId,omitempty"`

	// Find by vnfDevices ID
	// Required: false
	VNFDevID uint64 `url:"vnfDevId,omitempty" json:"vnfDevId,omitempty"`

	// Find by status
	// Required: false
	Status string `url:"status,omitempty" json:"status,omitempty"`

	// Sort by one of supported fields, format +|-(field)
	// Required: false
	SortBy string `url:"sortBy,omitempty" json:"sortBy,omitempty" validate:"omitempty,sortBy"`

	// Page number
	// Required: false
	Page uint64 `url:"page,omitempty" json:"page,omitempty"`

	// Page size
	// Required: false
	Size uint64 `url:"size,omitempty" json:"size,omitempty"`

	//openVswitch bridge name
	//Required: false
	OVSBridge string `url:"ovsBridge,omitempty" json:"ovsBridge,omitempty"`
}

// List gets list of all available external networks as a ListExtNets struct
func (e ExtNet) List(ctx context.Context, req ListRequest) (*ListExtNets, error) {

	res, err := e.ListRaw(ctx, req)
	if err != nil {
		return nil, err
	}

	list := ListExtNets{}

	err = json.Unmarshal(res, &list)
	if err != nil {
		return nil, err
	}

	return &list, nil
}

// ListRaw gets list of all available external networks as an array of bytes
func (e ExtNet) ListRaw(ctx context.Context, req ListRequest) ([]byte, error) {

	if err := validators.ValidateRequest(req); err != nil {
		return nil, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudapi/extnet/list"

	res, err := e.client.DecortApiCall(ctx, http.MethodPost, url, req)
	return res, err
}
