package dpdknet

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// DeleteRequest struct to delete DPDK network
type DeleteRequest struct {
	// ID of DPDK network to delete
	// Required: true
	DPDKID uint64 `url:"dpdkId" json:"dpdkId" validate:"required"`
}

// Delete deletes DPDK network by ID
func (d DPDKNet) Delete(ctx context.Context, req DeleteRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/dpdknet/delete"

	res, err := d.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
