package image

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// RevokeAccessRequest struct to unshare image with accounts
type RevokeAccessRequest struct {
	// ID of the image to unshare
	// Required: true
	ImageID uint64 `url:"imageId" json:"imageId" validate:"required"`

	// ID of the accounts for unshare image
	// Required: true
	AccountIDs []int64 `url:"accounts" json:"accounts" validate:"required"`
}

// RevokeAccess unshares specified image with specified accounts
func (i Image) RevokeAccess(ctx context.Context, req RevokeAccessRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/image/revokeAccess"

	res, err := i.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
