package node

import (
	"context"
	"net/http"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// SetSRIOVStatusRequest struct to set Single-root input/output virtualization kernel config on node
type SetSRIOVStatusRequest struct {
	// Node ID
	// Required: true
	NID uint64 `url:"nid" json:"nid" validate:"required"`

	// Enabled
	// Required: true
	Enabled bool `url:"enabled" json:"enabled" validate:"required"`
}

// SetSRIOVStatus sets Single-root input/output virtualization kernel config on node
func (n Node) SetSRIOVStatus(ctx context.Context, req SetSRIOVStatusRequest) (string, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return "", validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/node/setsriovstatus"

	res, err := n.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return "", err
	}

	return string(res), nil
}
