package node

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// SetVFsNumberRequest struct to set number of VFs for individual NIC on node
type SetVFsNumberRequest struct {
	// Node ID
	// Required: true
	NID uint64 `url:"nid" json:"nid" validate:"required"`

	// PCI address or NIC name
	// Required: true
	NICID string `url:"nicId" json:"nicId" validate:"required"`

	// Number of VF to assign
	// Required: true
	VFNum uint64 `url:"vfNum" json:"vfNum" validate:"required"`

	// Number of VF to assign
	// Required: true
	VFParams []VFParam `url:"vfParams" json:"vfParams" validate:"required"`
}

// SetVFsNumber sets number of VFs for individual NIC on node
func (n Node) SetVFsNumber(ctx context.Context, req SetVFsNumberRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/node/setVFsNumber"

	res, err := n.client.DecortApiCall(ctx, http.MethodPost, url, req)

	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
