package prometheus

import (
	"context"
	"encoding/json"
	"net/http"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

type ComputeWriteRequestsRequest struct {
	// Compute ID
	// Required: true
	ComputeID uint64 `url:"computeId" json:"computeId" validate:"required"`

	// Time to loads of statistic in seconds
	// Required: false
	ForLast uint64 `url:"forLast,omitempty" json:"forLast,omitempty"`

	// The reading interval in seconds
	// Required: false
	Step uint64 `url:"step,omitempty" json:"step,omitempty"`

	// Number of zeros after the decimal point
	// Required: false
	DecimalPlaces uint64 `url:"decimalPlaces,omitempty" json:"decimalPlaces,omitempty"`
}

// Write Requests
func (p Prometheus) ComputeWriteRequests(ctx context.Context, req ComputeWriteRequestsRequest) (*PrometheusData, error) {
	res, err := p.ComputeWriteRequestsRaw(ctx, req)
	if err != nil {
		return nil, err
	}

	info := PrometheusData{}

	err = json.Unmarshal(res, &info)
	if err != nil {
		return nil, err
	}

	return &info, nil
}

// GetRaw gets information about compute as an array of bytes
func (p Prometheus) ComputeWriteRequestsRaw(ctx context.Context, req ComputeWriteRequestsRequest) ([]byte, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return nil, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/prometheus/computeWriteRequests"

	res, err := p.client.DecortApiCall(ctx, http.MethodPost, url, req)
	return res, err
}
