package stack

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// GetLogicalCoresCountRequest struct to get logical cores count by stack
type GetLogicalCoresCountRequest struct {
	// Stack ID
	// Required: true
	StackId uint64 `url:"stackId" json:"stackId" validate:"required"`
}

// GetLogicalCoresCount get logical cores count by stack
func (i Stack) GetLogicalCoresCount(ctx context.Context, req GetLogicalCoresCountRequest) (uint64, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return 0, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/stack/getLogicalCoresCount"

	res, err := i.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return 0, err
	}

	result, err := strconv.ParseUint(string(res), 10, 64)
	if err != nil {
		return 0, err
	}

	return result, nil
}
