package stack

import (
	"context"
	"encoding/json"
	"net/http"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// SetMemAllocationRatioRequest struct to set memory allocation ratio
type SetMemAllocationRatioRequest struct {
	// Stack ID
	// Required: true
	StackId uint64 `url:"stackId" json:"stackId" validate:"required"`

	// Allocation ratio (zero or positive value)
	// Required: true
	Ratio float64 `url:"ratio" json:"ratio" validate:"required"`
}

// SetMemAllocationRatio set memory allocation ratio
func (i Stack) SetMemAllocationRatio(ctx context.Context, req SetMemAllocationRatioRequest) (*InfoStack, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return nil, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/stack/setMemAllocationRatio"

	res, err := i.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return nil, err
	}

	info := InfoStack{}

	err = json.Unmarshal(res, &info)
	if err != nil {
		return nil, err
	}

	return &info, nil
}
